@@ -847,8 +847,6 @@ printNet <- function(x){
   }
 }
 
-print <- function(x, ...) UseMethod("print")
-
 plot.coin <- function(x, dir=tempdir(), language=c("en","es"), ...){
   N <- asNodes(x)
   E <- edgeList(x,"frequency","expected")
@@ -867,8 +865,6 @@ plot.timeCoin <- function(x, dir=tempdir(), language=c("en","es"), ...){
      timeCreate(x,language,dir,TRUE)
 }
 
-plot <- function(x, ...) UseMethod("plot")
-
 summary.coin <- function(object, ...){
   cat(object$n,"scenarios and", dim(object$f)[1], "events\n")
   diag(object$f)/object$n
@@ -911,8 +907,6 @@ summaryNet <- function(x){
        }
 }
 
-summary <- function(object, ...) UseMethod("summary")
-
 # Transform a coin object into a data frame with name and frequency
 asNodes<-function(C,frequency=TRUE,percentages=FALSE,language="en"){
   if (class(C)=="coin") {
