@@ -1,11 +1,8 @@
 // texts to translate
 var texts = {
-    selection : "Filtration",
-    netselection : "Graph selection",
-    visualization : "Visualization",
+    netselection : "Graph",
     nodes : "Nodes",
     general: "General",
-    particular: "Specific",
     links: "Links",
     apply: "Apply",
     filter: "Filter",
@@ -23,22 +20,23 @@ var texts = {
     loading: "Loading...",
     pdfexport: "PDF export",
     svgexport: "SVG export",
-	adjustsymbols: "Adjust symbols",
+    adjustsymbols: "Adjust symbols",
     showhidelabels: "Show/hide labels",
     showhidelegend: "Show/hide legend",
     showhideaxes: "Show/hide axes",
     showhideimages: "Show/hide images",
     showhidesidebar: "Show/hide sidebar",
     stopresume: "Stop/resume",
-	netheatmap: "Net/heatmap",
+    netheatmap: "Net/heatmap",
     isolateselection: "Filter selection",
     resetfilter: "Reset filter",
     selectall: "Select all/none",
     selectneighbors: "Add neighbors",
     egoNet: "EgoNet",
+    expandcollapse: "Expand/collapse",
     tableselection: "Matched in table",
     reset: "Reset",
-    directional: "Directional arrows",
+    directional: "Show/hide arrows",
     degree: "degree",
     none: "none",
     downloadtable: "Download table",
@@ -54,15 +52,15 @@ var texts = {
     subjectselect: "Event selection",
     Label: "Label",
     Group: "Group",
-	OrderA: "A Order",
-	OrderD: "D Order",
+    OrderA: "A Order",
+    OrderD: "D Order",
     Size: "Size",
     Color: "Color",
     Shape: "Shape",
-    Slegend: "Slegend",
+    Legend: "Legend",
     Width: "Width",
     Weight: "Weight",
-	Intensity: "Intensity",
+    Intensity: "Intensity",
     Text: "Text",
     Show: "Show",
     Hide: "Hide",
@@ -72,8 +70,7 @@ var texts = {
     square: "square",
     "triangle-down": "triangle-down",
     "triangle-up": "triangle-up",
-	trianglesquare: "Triangle/square",
-	selectacolorscale: "Select a color scale for ",
-    selecta: "Select a ",
-	outof: "out of"
+    trianglesquare: "Triangle/square",
+    selectacolorscale: "Select a color scale for ",
+    outof: "out of"
   };
