@@ -1,11 +1,8 @@
 // texts to translate
 var texts = {
-    selection : "Selección",
-    netselection : "Selección de gráfico",
-    visualization : "Visualización",
+    netselection : "Gráfico",
     nodes : "Nodos",
     general: "General",
-    particular: "Particular",
     links: "Enlaces",
     apply: "Aplicar",
     filter: "Filtrar",
@@ -23,22 +20,23 @@ var texts = {
     loading: "Cargando...",
     pdfexport: "Exportación PDF",
     svgexport: "Exportación SVG",
-	adjustsymbols: "Fijar símbolos",
+    adjustsymbols: "Fijar símbolos",
     showhidelabels: "Mostrar/ocultar etiquetas",
     showhidelegend: "Mostrar/ocultar leyenda",
     showhideaxes: "Mostrar/ocultar ejes",
     showhideimages: "Mostrar/ocultar imágenes",
     showhidesidebar: "Mostrar/ocultar control lateral",
     stopresume: "Parar/reanudar",
-	netheatmap: "Red/mapa de color",
+    netheatmap: "Red/mapa de color",
     isolateselection: "Filtrar selección",
     resetfilter: "Quitar filtro",
     selectall: "Seleccionar todos/ninguno",
     selectneighbors: "Añadir vecinos",
     egoNet: "EgoRed",
+    expandcollapse: "Expandir/contraer",
     tableselection: "Marcados en la tabla",
     reset: "Reiniciar",
-    directional: "Direccional",
+    directional: "Mostrar/ocultar flechas",
     degree: "grado",
     none: "Nada",
     downloadtable: "Descargar tabla",
@@ -54,15 +52,15 @@ var texts = {
     subjectselect: "Selección de eventos",
     Label: "Etiqueta",
     Group: "Grupo",
-	OrderA: "A Orden",
-	OrderD: "D Orden",
+    OrderA: "A Orden",
+    OrderD: "D Orden",
     Size: "Tamaño",
     Color: "Color",
     Shape: "Forma",
-    Slegend: "Sleyenda",
+    Legend: "Leyenda",
     Width: "Anchura",
-    Weight: "Ponderación",
-	Intensity: "Intensidad",
+    Weight: "Peso",
+    Intensity: "Intensidad",
     Text: "Texto",
     Show: "Mostrar",
     Hide: "Ocultar",
@@ -72,8 +70,7 @@ var texts = {
     square: "Cuadrado",
     "triangle-down": "Triangulo-abajo",
     "triangle-up": "Triangulo-arriba",
-	trianglesquare: "Triángulo/cuadrado",
-	selectacolorscale: "Selecciona una escala de color para ",
-    selecta: "Selecciona un/una ",
-	outof: "de"
+    trianglesquare: "Triángulo/cuadrado",
+    selectacolorscale: "Selecciona una escala de color para ",
+    outof: "de"
   };
